@@ -29,4 +29,4 @@ def fixpage(page, count=[0]):
 inpfn, = sys.argv[1:]
 outfn = 'print_two.' + os.path.basename(inpfn)
 pages = PdfReader(inpfn).pages
-PdfWriter().addpages(fixpage(x) for x in pages).write(outfn)
+PdfWriter(outfn).addpages(fixpage(x) for x in pages).write()
